Contributors
============

Leads:

- `@ericmjl <https://github.com/ericmjl/pyjanitor/pulls?q=is%3Apr+author%3Aericmjl>`_
- `@szuckerman <https://github.com/ericmjl/pyjanitor/pulls?q=is%3Apr+author%3Aszuckerman>`_
- `@zbarry <https://github.com/zbarry>`_

With thanks to the following contributors:

- `@JoshuaC3 <https://github.com/ericmjl/pyjanitor/pulls?q=is%3Apr+author%3AJoshuaC3>`_
- `@HectorM14 <https://github.com/HectorM14>`_
- `@cduvallet <https://github.com/cduvallet>`_
- `@shantanuo <https://github.com/shantanuo>`_
- `@jcvall <https://github.com/jcvall>`_
- `@CWen001 <https://github.com/CWen001>`_
- `@bhallaY <https://github.com/bhallaY>`_
- `@jekwatt <https://github.com/jekwatt>`_
- `@kurtispinkney <https://github.com/kurtispinkney>`_
- `@lphk92 <https://github.com/lphk92>`_
- `@jonnybazookatone <https://github.com/jonnybazookatone>`_
- `@SorenFrohlich <https://github.com/SorenFrohlich>`_
- `@dave-frazzetto <https://github.com/dave-frazzetto>`_
- `@dsouzadaniel <https://github.com/dsouzadaniel>`_
- `@Eidhagen <https://github.com/Eidhagen>`_
- `@mdini <https://github.com/mdini>`_
- `@kimt33 <https://github.com/kimt33>`_
- `@jack-kessler-88 <https://github.com/jack-kessler-88>`_
- `@NapsterInBlue <https://github.com/NapsterInBlue>`_
- `@jk3587 <https://github.com/jk3587>`_
- `@ricky-lim <https://github.com/ricky-lim>`_
- `@catherinedevlin <https://github.com/catherinedevlin>`_
- `@StephenSchroed <https://github.com/StephenSchroeder>`_
- `@Rajat-181 <https://github.com/Rajat-181>`_
